==> formide-cli-1.0.6.tgz: package/lib/api.js <==
process.env.NODE_TLS_REJECT_UNAUTHORIZED = "0"; // ugly hack!

var request		= require('request');
var _			= require('underscore');
var apiRoot 	= 'https://api2.formide.com/';
var fs			= require('fs');

var call = function(options, callback) {
	
	// create the options object with defaults
	options = _.extend({
		path			: '/',
		method			: 'GET',
		access_token	: lib.settings.accessToken,
		refresh_token	: lib.settings.refreshToken,
		json			: true,
		appUpload		: false
	}, options);
	
	// make the request
	var r = request({
		method	: options.method,
		url		: apiRoot + options.path,
		json	: options.json,
		headers	: {
			'Authorization': 'Bearer ' + options.access_token
		}
	}, function(err, response, body) {
		if (err) return callback(err);
		if (response.statusCode == 401) {
			return console.log('Access token expired');
/*
			request({
				method: 'POST',
				url: 'https://sdk.athom.com/auth/refresh',
				json: {
					'refresh_token': options.refresh_token
				}
			}, function(err, result, body) {
				console.log(body)
			});
*/
		}
		
		if (typeof callback == 'function') {
			callback(null, response, body);
		}
	});
	
	// when app is uploaded, add upload multipart form
	if(options.appUpload) {
		var form = r.form();
		form.append('version', options.appUpload.version); // TODO: auto update manifest version after upload?
		form.append('app_id', options.appUpload.id);
		form.append('app_file', fs.createReadStream(options.appUpload.zipPath, {filename: 'app.zip', contentType: 'application/zip'}));
	}
};

module.exports.call = call;

==> formide-cli-1.0.9.tgz: package/lib/api.js <==
process.env.NODE_TLS_REJECT_UNAUTHORIZED = "0"; // ugly hack!

var request		= require('request');
var _			= require('underscore');
var apiRoot 	= 'https://api2.formide.com/';
var fs			= require('fs');

var call = function(options, callback) {
	
	// create the options object with defaults
	options = _.extend({
		path			: '/',
		method			: 'GET',
		access_token	: lib.settings.accessToken,
		refresh_token	: lib.settings.refreshToken,
		json			: true,
		appUpload		: false
	}, options);
	
	// make the request
	var r = request({
		method	: options.method,
		url		: apiRoot + options.path,
		json	: options.json,
		headers	: {
			'Authorization': 'Bearer ' + options.access_token
		}
	}, function(err, response, body) {
		if (err) return callback(err);
		if (response.statusCode == 401) {
			return console.log('Access token expired. Retrieving new access token with refresh token.');
			request({
				method: 'POST',
				url: 'https://sdk.formide.com/auth/refresh',
				json: {
					'refresh_token': options.refresh_token
				}
			}, function(err, result, body) {
				console.log(body)
			});
		}
		
		if (typeof callback == 'function') {
			callback(null, response, body);
		}
	});
	
	// when app is uploaded, add upload multipart form
	if(options.appUpload) {
		var form = r.form();
		form.append('version', options.appUpload.version); // TODO: auto update manifest version after upload?
		form.append('app_id', options.appUpload.id);
		form.append('app_file', fs.createReadStream(options.appUpload.zipPath, {filename: 'app.zip', contentType: 'application/zip'}));
	}
};

module.exports.call = call;
